@@ -976,7 +976,7 @@
 ;;; The tag name is a command to open the file containing that source
 (define (InsertLink filepos)
   (d-Directive-standalone  "DenemoLink")
-  (d-DirectivePut-standalone-postfix "DenemoLink" (string-append "%{" filepos "%}"))
+  (d-DirectivePut-standalone-postfix "DenemoLink" (string-append "%" filepos "\n"))
   (d-DirectivePut-standalone-data "DenemoLink" filepos)
   (d-DirectivePut-standalone-minpixels "DenemoLink" 30)
   (d-DirectivePut-standalone-graphic "DenemoLink" "\n⬁\ndenemo\n24")
@@ -986,13 +986,15 @@
   
 
 ;;; The routine called by the DenemoLink command to follow the link
-;(define (FollowLink)
-;  (let ((link (d-DirectiveGet-standalone-postfix "DenemoLink")))
-;    (if link
-;     (begin
-     ;(disp "link is " link "ok\n")
-;      (set! link (string-trim-both link   (lambda (c)(or (eqv? c #\{) (eqv? c #\%)))))
-;  (d-OpenSource link)))))
+(define (DenemoFollowLink)
+  (let ((link (d-DirectiveGet-standalone-data "DenemoLink")))
+    (if (not link)
+        (begin
+            (set! link (d-DirectiveGet-standalone-postfix "DenemoLink"))
+                (if link
+                    (set! link (string-trim-both link   (lambda (c)(or (eqv? c #\{) (eqv? c #\%))))))))
+        (if link
+            (d-OpenSource link))))
 
 ;;;; Routines for audio annotation
 (define (DenemoAudioAnnotation timing)
@@ -1033,8 +1035,8 @@
         (if (not (zero? (logand override DENEMO_OVERRIDE_DYNAMIC)))
             (eval-string (string-append "(d-" tag " 'recalculate)"))))))
 ;;;;;;
-(define (GetEditOption)
-    (define  choice (d-GetOption  (string-append cue-Edit stop  cue-Delete stop cue-Advanced stop)))
+(define* (GetEditOption #:optional (title (_ "Select from List (or Cancel)")))
+    (define  choice (d-GetOption  (string-append cue-Edit stop  cue-Delete stop cue-Advanced stop) title))
    (cond
      ((boolean? choice)
       'cancel)
@@ -1264,8 +1266,8 @@
                 (if (and (not score) (not (d-Directive-scoreheader? "ScoreTitles")))
                         (DenemoSetTitles "ScoreTitles" 'initialize #f))))
                         
-(define (form-pair name title)
-    (string-append "(cons '" name (if (string? title) (string-append " \"" (scheme-escape title) "\"") " #f") ")"))
+    (define (form-pair name title)
+        (string-append "(cons '" name (if (string? title) (string-append " \"" (scheme-escape title) "\"") " #f") ")"))
 ;;; procedure starts here
         (if score
             (set! data (d-DirectiveGet-scoreheader-data tag))
