@@ -31,6 +31,7 @@
 #define GRACED_NOTE (1<<1) /*Note is an (appogiatura) grace note */
 #define ENDGRACE (1<<2) /*Note is last grace note in a group */
 #define ACCIACCATURA (1<<3) /*Note is an acciacatura grace note */
+#define DURATION_SET (1<<4) /*Note has been assigned a duration (stored in durinticks) */
 
 
 typedef void (*GActionCallback) (GtkAction *action, gpointer data);
@@ -445,7 +446,7 @@ enum
   COL_ROW,
   COL_SCHEME,
   N_COLUMNS
-} COMMAND_COLS;
+};
 
 typedef enum { TYPESET_EXCERPT, TYPESET_MOVEMENT, TYPESET_ALL_MOVEMENTS} typeset_type;
 
@@ -473,6 +474,7 @@ typedef struct DenemoPrefs
   gint pitchspellingchannel; /**< channel to use for feedback when entering extreme intervals via MIDI in, that may indicate an enharmonic error, 0 means no pitch spelling*/
   gint pitchspellingprogram; /**< program to set pitchspellingchannel to on startup */
   gboolean startmidiin; /**< try to start midi in on startup */
+  gboolean notesonlymidiin; /**< whether to ignore MIDI signals other than note on/off from MIDI in source. */
   gboolean applytoselection; /**< apply commands to selection */
 
   gboolean quickshortcuts;/**< TRUE if pressing a key while hovering over a menu item sets a shortcut */
@@ -914,6 +916,10 @@ typedef struct DenemoScrollPoint {
      gdouble time, adj;
      gdouble x, y;
 } DenemoScrollPoint;
+typedef struct DenemoOmissionCriterion {
+     gchar *name;
+     guint32 id;
+} DenemoOmissionCriterion;
 
 /*
  *  DenemoScore structure representing a single movement of a piece of music.
@@ -1087,6 +1093,8 @@ typedef struct DenemoProject
   GList *custom_scoreblocks; /**< List of customized  \score blocks for LilyPond output, elements are DenemoScoreblock * */
   GtkWidget *score_layout; /**< The window in which custom_scoreblock widgets are placed */
   guint layout_id; /**< cached value of the currently selected layout id */
+  DenemoOmissionCriterion *criterion; /**< an omission criterion chosen by the user to avoid directives marked to ignore this name - a lightweight score layout in effect. */
+  GList *criteria; /**< a list of DenemoOmissionCriterion which have been defined for this score */
   GList *callbacks;/**< scheme callbacks on deletion */
   gpointer lilystart, lilyend; /**<range of lilytext  */
   GString **target; /**< pointer to target string for modification in lilytext  */
@@ -1258,6 +1266,7 @@ struct DenemoRoot
   gboolean *silent; /** Don't log any message */
   gboolean *verbose; /** Display every messages */
   guint pending_layout_id;//Non zero when the current layout being created will be renamed to have this id 
-}  Denemo; /**< The root object. */
+};
 
+extern struct DenemoRoot Denemo; /**< The root object. */
 #endif
