@@ -36,6 +36,7 @@
 #include <glib.h>
 #include <string.h>
 #include <stdint.h>
+#include <math.h>
 
 static backend_t *backends[NUM_BACKENDS] = { NULL };
 
@@ -575,7 +576,25 @@ get_playback_time (void)
   return playback_time;
 }
 
+#ifdef _HAVE_JACK_
+void midi_play(gchar *callback) {
+  generate_midi();
 
+  reset_playback_queue(AUDIO_BACKEND);
+  reset_playback_queue(MIDI_BACKEND);
+
+  g_print("JACK starting playback\n");
+
+  playback_start_time = get_start_time();
+  playback_time = playback_start_time;
+
+  start_playing(callback);
+
+  get_backend(AUDIO_BACKEND)->start_playing();
+  get_backend(MIDI_BACKEND)->start_playing();
+}
+
+#else
 void
 midi_play (gchar * callback)
 {
@@ -587,14 +606,16 @@ midi_play (gchar * callback)
   g_message ("Starting playback");
   start_playing (callback);
   do {//FIXME, this is a crude attempt to get the playback_time set without the callback from portaudio re-writing it.
-  playback_time = playback_start_time;
+    playback_time = playback_start_time;
     time_reset = TRUE;
     playback_time = playback_start_time;
     get_backend (AUDIO_BACKEND)->start_playing ();// this must pick up the playback_start_time, which won't happen if an interrrupt has occurred meanwhile.
-    } while(playback_time != playback_start_time);
-  g_message ("Starting playback at %f", playback_start_time);
+    } while(fabs(playback_time - playback_start_time) > 0.0001);
+  g_message ("Starting playback at %f - should be %f", playback_start_time, playback_time);
   get_backend (MIDI_BACKEND)->start_playing ();
 }
+#endif
+
 
 void
 audio_play (void)
