@@ -161,6 +161,8 @@ perform_command (const gchar * command_name, GdkEventKey * event)
   if (Denemo.project->movement)
     displayhelper (Denemo.project);
 #endif
+  g_string_printf (Denemo.input_filters, "%s  <span foreground=\"Green\">%s.</span> <span foreground=\"blue\">%s</span>", command_name, _("Help"), _("(use Fn12 to Repeat)"));
+  write_input_status();
   return NULL;
 }
 
@@ -177,7 +179,9 @@ process_key_event (GdkEventKey * event, gchar * perform_command ())
       set_cursor_for (state);   // MUST LOOK AHEAD to state after keypress HERE CATCH modifiers and set the cursor for them.....
   }
   dnm_clean_event (event);
-
+  static guint last_keyval;
+  gboolean repeated_key =  (event->keyval==last_keyval);
+  last_keyval = event->keyval;
 
   if (isModifier (event))
     return NULL;
@@ -189,6 +193,7 @@ process_key_event (GdkEventKey * event, gchar * perform_command ())
     prefix_store = g_string_new ("");
 
   gint command_idx = lookup_command_for_keyevent (event);
+
   if ((prefix_store->len == 0) && (command_idx != -1))
     {
       const gchar *command_name = lookup_name_from_idx (the_keymap, command_idx);
@@ -205,6 +210,7 @@ process_key_event (GdkEventKey * event, gchar * perform_command ())
                 append_scheme_call ((gchar *) command_name);
             }
           //g_debug("Single Key shortcut %s invokes %s\n", dnm_accelerator_name(event->keyval, event->state), command_name);
+          Denemo.LastCommandId = command_idx;
           return perform_command (command_name, event);
         }
       else
@@ -237,6 +243,7 @@ process_key_event (GdkEventKey * event, gchar * perform_command ())
                 {
                 append_scheme_call ((gchar *) command_name);
                 }
+              Denemo.LastCommandId = command_idx;
               ret = perform_command (command_name, event);
             }
         }
@@ -252,6 +259,7 @@ process_key_event (GdkEventKey * event, gchar * perform_command ())
           toggle_to_drawing_area (TRUE);        //restore menus, in case the user is lost and needs to look up a keypress
           if (Denemo.project->view != DENEMO_MENU_VIEW)
                         toggle_to_drawing_area (TRUE);
+
         }
       g_string_assign (prefix_store, "");
       Denemo.continuations = NULL;
@@ -284,12 +292,17 @@ process_key_event (GdkEventKey * event, gchar * perform_command ())
         {
           if ((Denemo.project->view != DENEMO_MENU_VIEW) || Denemo.prefs.learning)
             {
-                            Denemo.prefs.learning = TRUE;
+              Denemo.prefs.learning = TRUE;
               KeyStrokeDecline (name);
             }
           toggle_to_drawing_area (TRUE);  //restore menus, in case the user is lost and needs to look up a keypress
           if (Denemo.project->view != DENEMO_MENU_VIEW)
-                        toggle_to_drawing_area (TRUE);
+              toggle_to_drawing_area (TRUE);
+          if (repeated_key)
+             {
+               Denemo.prefs.learning = TRUE;
+               KeyStrokeShow (name, command_idx, TRUE);
+             }
         }
       return NULL;
     }
@@ -305,6 +318,18 @@ process_key_event (GdkEventKey * event, gchar * perform_command ())
 gint
 scorearea_keypress_event (GtkWidget * widget, GdkEventKey * event)
 {
+  //g_print ("Scorearea key press event: keyval %d (%s), string |%s|, length %d, state %x, keycode %d, group %d, is_modifier flag %d\n", event->keyval, gdk_keyval_name(event->keyval), event->string, event->length, event->state, event->hardware_keycode, event->group, event->is_modifier);
+  if ((event->keyval == 65481) && (event->state == 0)) //Fn12 hardwired to repeat last command
+    {
+      if (Denemo.LastCommandId != -1)
+        {
+          execute_callback_from_idx (Denemo.map, Denemo.LastCommandId);
+          g_string_assign (Denemo.input_filters, _("<span foreground=\"green\">Fn12</span>: Repeated Last Command"));
+          write_input_status();
+        }
+      return TRUE;
+    }
+
       if(!Denemo.keyboard_state_locked)
           {
               Denemo.keyboard_state |= (0xf & klock_mask (event->keyval));
@@ -324,7 +349,7 @@ scorearea_keypress_event (GtkWidget * widget, GdkEventKey * event)
       gtk_main_quit ();
       return TRUE;              //*is* reached main loop exits to the caller of the loop when it next gains control
     }
-
+ 
   (void) process_key_event (event, perform_command);
   return TRUE;                  //I think this means do not run any other handlers after this.
 }
@@ -1002,7 +1027,7 @@ static void Dur (gint duration) {
 /*******************************************************************************
 * NOTE COMMANDS
 ******************************************************************************/
-static change_note_to (gchar note)//CHECK executing (d-ChangeToA)
+static void change_note_to (gchar note)//CHECK executing (d-ChangeToA)
 {
   gint mode = Denemo.project->mode;
   Denemo.project->last_source = INPUTKEYBOARD;
