@@ -182,9 +182,9 @@
 {"SetInitialBflatmin", NULL, N_("Set Bb Minor as Initial Keysig"), "",N_("No Tooltip yet"),G_CALLBACK (keysig_set_bflatmin)},
 {"SetInitialEflatmin", NULL, N_("Set Eb Minor as Initial Keysig"), "",N_("No Tooltip yet"),G_CALLBACK (keysig_set_eflatmin)},
 {"SetInitialAflatmin", NULL, N_("Set Ab Minor as Initial Keysig"), "",N_("No Tooltip yet"),G_CALLBACK (keysig_set_aflatmin)},
-{"SetMark", NULL, N_("Set Mark"), "",N_("Sets the start point for a selection,\nthe end point of the selection is unaltered"),G_CALLBACK (set_mark)},
-{"UnsetMark", NULL, N_("Unset Mark"), "",N_("Gets rid of the selection."),G_CALLBACK (unset_mark)},
-{"SetPoint", NULL, N_("Set Point"), "",N_("Extends the selection to the current cursor position"),G_CALLBACK (set_point)},
+{"SetMark", NULL, N_("Set Selection Start"), "",N_("Sets the start and end point of the selection to the object at the cursor."),G_CALLBACK (set_mark)},
+{"UnsetMark", NULL, N_("Drop the Selection"), "",N_("Gets rid of the selection."),G_CALLBACK (unset_mark)},
+{"SetPoint", NULL, N_("Extend Selection to Cursor"), "",N_("Extends and existing selection to the current cursor position  (selection start must have been set)"),G_CALLBACK (set_point)},
 {"ToggleBeginSlur", NULL, N_("Begin Slur (Off/On)"), "",N_("Insert/delete begin slur on this note"),G_CALLBACK (toggle_begin_slur)},
 {"ToggleEndSlur", NULL, N_("End Slur (Off/On)"), "",N_("Insert/delete end slur on this note"),G_CALLBACK (toggle_end_slur)},
 {"ToggleStartCrescendo", NULL, N_("Start Crescendo (Off/On)"), "",N_("Marks/Unmarks the chord or note at the cursor as the start of a crescendo."),G_CALLBACK (toggle_start_crescendo)},
@@ -257,7 +257,7 @@
 {"Undo", GTK_STOCK_UNDO, N_("Undo"), "",N_("Undoes one (more) step of your edits to the music in the Display Window. Does not work for titles, settings etc - repeat the command for those."),G_CALLBACK (undowrapper)},
 {"Redo", GTK_STOCK_REDO, N_("Redo"), "",N_("Redoes the next of the steps you have Undone"),G_CALLBACK (redowrapper)},
 {"Select", NULL, N_("Select"), "",N_("Selecting stretches of notes")},
-{"ExtendSelect", NULL, N_("Extend Selection"), "",N_("Extend the selection")},
+{"ExtendSelect", NULL, N_("Create and Extend Selection"), "",N_("Create/Extend the selection.")},
 {"Copy", GTK_STOCK_COPY, N_("Copy"), "",N_("Copy the music selected to the Denemo clipboard"),G_CALLBACK (copywrapper)},
 {"Cut", GTK_STOCK_CUT, N_("Cut"), "",N_("Cut the music selected to the Denemo clipboard"),G_CALLBACK (cutwrapper)},
 {"Paste", GTK_STOCK_PASTE, N_("Paste"), "",N_("Paste the Denemo clipboard into the score where the cursor is positioned"),G_CALLBACK (pastewrapper)},
