@@ -140,25 +140,36 @@ get_or_create_command(gchar* name){
   return command;
 }
 
+
 void
 dnm_clean_event (GdkEventKey * event)
-{
+{ 
   if (!Denemo.prefs.strictshortcuts)
     {
-      guint ret;
-      //g_debug("Called %s\n", gdk_keyval_name(event->keyval));
-      gdk_keymap_translate_keyboard_state (gdk_keymap_get_default (), event->hardware_keycode, GDK_MOD2_MASK /*NumLock forcing numeric keypad to give numbers */ ,
-                                           0 /*group 0 */ , &ret, NULL, NULL, NULL);
-      if (ret >= 'A' && ret <= 'G')
+      guint ret = event->keyval;
+      if (ret >= 'A' && ret <= 'Z')
         ret += ('a' - 'A');
+#ifdef G_OS_WIN32
+      else
+        if (event->hardware_keycode>47 && event->hardware_keycode<58)
+          {
+            ret = event->hardware_keycode;
+          }
+#else
+      else
+        if (event->hardware_keycode>9 && event->hardware_keycode<20)
+          {
+            ret = 39 + event->hardware_keycode;
+            if (ret==58)
+              ret = 48;
+          }
+#endif
       event->keyval = ret;
-
-      //g_debug("Changed to %s\n", gdk_keyval_name(event->keyval));
     }
+  //g_print("Hardware key %d Key val has been cleaned to %d -> %s\n", event->hardware_keycode, event->keyval, gdk_keyval_name(event->keyval));
 }
 
 
-
 /* Returns the state of the event after removing the modifiers consumed by the
  * system and unwanted modifiers. Use this before doing anything based on the
  * (keyval, state) pair in an event handler.
@@ -185,50 +196,6 @@ dnm_sanitize_key_state (GdkEventKey * event)
   return ret;
 }
 
-/* Returns the state of the event after removing the modifiers consumed by the
- * system and even more unwanted modifiers. Use this if sanitize is insufficient.
- */
-guint
-dnm_hyper_sanitize_key_state (GdkEventKey * event)
-{
-  guint ret = event->state;
-#if 1
-  GdkModifierType consumed;
-  /* We want to ignore irrelevant modifiers like ScrollLock */
-
-  gdk_keymap_translate_keyboard_state (gdk_keymap_get_default (), event->hardware_keycode, event->state, event->group, NULL, NULL, NULL, &consumed);
-  /* removing consumed modifiers from ret */
-  ret &= ~consumed;
-  /* removing other unwanted modifiers from event->state */
-  ret &= (GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK);
-#endif
-  return ret;
-}
-
-/* Returns the state of the event as for hyper_sanitize
- * additionally undoes the effect of CapsLock on keyval when Shift is not pressed.
- * note that event->keycode & keystring are not altered, leaving event inconsistent.
- * this could conceivably become a problem in other developments.
- * Use this if hyper sanitize is insufficient.
- */
-guint
-dnm_meta_sanitize_key_state (GdkEventKey * event)
-{
-  guint ret = event->state;
-#if 1
-  if (ret & GDK_LOCK_MASK)
-    {
-      if (!(ret & GDK_SHIFT_MASK))
-        event->keyval += ('a' - 'A');
-    }
-
-  /* removing everything other than control shift and alt modifiers from event->state */
-  ret &= (GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK);
-#endif
-  return ret;
-}
-
-
 
 /*
  * Returns True if the key event is just a modifier key, False otherwise
@@ -436,7 +403,6 @@ dnm_accelerator_parse (const gchar * accelerator, guint * accelerator_key, GdkMo
 //}
 // if((gdk_keymap_get_caps_lock_state (gdk_keymap_get_default())!=0) != ((accelerator_mods&GDK_SHIFT_MASK)!=0))
 
-
 gchar *
 dnm_accelerator_name (guint accelerator_key, GdkModifierType accelerator_mods)
 {
@@ -446,12 +412,36 @@ dnm_accelerator_name (guint accelerator_key, GdkModifierType accelerator_mods)
       GString *name;
 
       name = g_string_new (gdk_keyval_name (accelerator_key));
+      //g_print ("Keyval %d gdk name %s\n", accelerator_key, name->str);
       if (name->len > 3 && (*name->str == 'K') && (*(name->str + 1) == 'P') && (*(name->str + 2) == '_'))
+#ifndef G_OS_WIN32  
+        {
+           if((*(name->str + 3) >='0') && (*(name->str + 3) <='6'))
+            g_string_erase (name, 0, 3);    //force numeric keypad KP_n names to normal except for 7 8 9 which are not needed for duration entry also ignore NumLock for these
+          else if(!strcmp(name->str, "KP_Insert"))
+                  g_string_assign (name, "0");
+          else if(!strcmp(name->str, "KP_Delete"))
+                  g_string_assign (name, "KP_Decimal");
+          else if(!strcmp(name->str, "KP_End"))
+                  g_string_assign (name, "1");
+          else if(!strcmp(name->str, "KP_Down"))
+                  g_string_assign (name, "2");
+          else if(!strcmp(name->str, "KP_Next"))
+                  g_string_assign (name, "3");
+          else if(!strcmp(name->str, "KP_Left"))
+                  g_string_assign (name, "4");
+          else if(!strcmp(name->str, "KP_Begin"))
+                  g_string_assign (name, "5");
+          else if(!strcmp(name->str, "KP_Right"))
+                  g_string_assign (name, "6");
+        }
+#else
         {
           if((*(name->str + 3) !='7') && (*(name->str + 3) !='8') && (*(name->str + 3) !='9'))
             g_string_erase (name, 0, 3);    //force numeric keypad KP_ names to normal except for 7 8 9 which are not needed for duration entry
         }
-      //g_debug("label %s\nname %s\n", gtk_accelerator_get_label(accelerator_key, 0), gdk_keyval_name(accelerator_key));
+#endif
+      //g_print("\ndnm_accelerator_name using gtk_accelerator_get label %s\n gdk_keyval_name name %s\n", gtk_accelerator_get_label(accelerator_key, 0), gdk_keyval_name(accelerator_key));
       //g_debug("mods were %x\n", accelerator_mods);
 #if 0
       //do not let caps lock affect shift of backspace etc
@@ -489,6 +479,7 @@ dnm_accelerator_name (guint accelerator_key, GdkModifierType accelerator_mods)
         g_string_prepend (name, "Mod4+");
       if ((accelerator_mods & GDK_MOD5_MASK))
         g_string_prepend (name, "Mod5+");
+      //g_print ("Transformed with mods 0x%x to name %s\n", accelerator_mods, name->str);
       return g_string_free (name, FALSE);
     }
 
@@ -606,6 +597,7 @@ dnm_accelerator_name (guint accelerator_key, GdkModifierType accelerator_mods)
 }
 
 
+
 /**
  * Warns user that there was no keymap available to load
  *
@@ -692,7 +684,7 @@ keymap_get_command_row (keymap * the_keymap, command_row ** row, guint command_i
     }
 
   if(g_hash_table_lookup (the_keymap->commands, &command_id) == NULL){
-    g_debug("Command not found");
+    g_debug("Command id %u not found", command_id);
     return FALSE;
   }
 
@@ -820,17 +812,6 @@ lookup_command_for_keyevent (GdkEventKey * event)
   keymap *the_keymap = Denemo.map;
   gint command_id = lookup_command_for_keybinding (the_keymap, event->keyval,
                                                     dnm_sanitize_key_state (event));
-#if 0
-  if (!Denemo.prefs.strictshortcuts)
-    {
-      //    lookup_command_for_keybinding (the_keymap, event->keyval,
-      //                             dnm_sanitize_key_state(event));
-      if (command_id == -1)
-        command_id = lookup_command_for_keybinding (the_keymap, event->keyval, dnm_hyper_sanitize_key_state (event));
-      if (command_id == -1)
-        command_id = lookup_command_for_keybinding (the_keymap, event->keyval, dnm_meta_sanitize_key_state (event));
-    }
-#endif
   return command_id;
 }
 
@@ -1349,7 +1330,11 @@ keymap_accel_quick_edit_snooper (GtkWidget * grab_widget, GdkEventKey * event, D
   GdkModifierType modifiers;
   keymap *the_keymap = Denemo.map;
   GtkMenu *menu = GTK_MENU (grab_widget);
-
+  if ((event->keyval == 65481) && (event->state == 0)) //Fn12 hardwired to repeat last command
+    {
+      warningdialog (_("Fn12 is hard-wired to repeat the last command"));
+      return FALSE;
+    }
   if (Denemo.prefs.menunavigation && ((event->keyval == 0xFF1B) || (event->keyval == 0xFF51) || (event->keyval == 0xFF52) || (event->keyval == 0xFF53) || (event->keyval == 0xFF54)))
     {
 //Esc and arrows for navigating menus
