@@ -103,7 +103,7 @@ initprefs ()
   ret->persistence = TRUE;
   ret->learning = TRUE;
   ret->immediateplayback = TRUE;
-  ret->measureswitchsound = 72;
+  ret->measureswitchsound = 75;
   ret->manualtypeset = FALSE;
   ret->typesetrefresh = 10;
   ret->typesettype = TYPESET_ALL_MOVEMENTS;
@@ -343,6 +343,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
         READBOOLXMLENTRY (applytoselection)
         READBOOLXMLENTRY (quickshortcuts)
         READBOOLXMLENTRY (startmidiin)
+        READBOOLXMLENTRY (notesonlymidiin)
         READINTXMLENTRY (mode)
         READBOOLXMLENTRY (strictshortcuts)
         READBOOLXMLENTRY (menunavigation)
@@ -427,6 +428,7 @@ get_bool_pref (gchar * prefname)
     GETBOOLPREF (applytoselection)
     GETBOOLPREF (quickshortcuts)
     GETBOOLPREF (startmidiin)
+    GETBOOLPREF (notesonlymidiin)
     GETBOOLPREF (strictshortcuts)
     GETBOOLPREF (menunavigation)
     GETBOOLPREF (overlays)
@@ -801,6 +803,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
     WRITEBOOLXMLENTRY (applytoselection)
     WRITEBOOLXMLENTRY (quickshortcuts)
     WRITEBOOLXMLENTRY (startmidiin)
+    WRITEBOOLXMLENTRY (notesonlymidiin)
     WRITEINTXMLENTRY  (mode)
     WRITEBOOLXMLENTRY (strictshortcuts)
     WRITEBOOLXMLENTRY (menunavigation)
