@@ -43,6 +43,9 @@
 #endif
 #endif
 
+gboolean compare_gstring (GString *g1, GString *g2);
+gboolean compare_glists (GList *l1, GList *l2);
+void localization_init (void);
 const gchar *get_user_data_dir (gboolean create);
 
 const gchar *locateprintdir (void);
@@ -154,6 +157,8 @@ gboolean choose_option (gchar * title, gchar * primary, gchar * secondary);
 gint choose_option_or_cancel (gchar * title, gchar * primary, gchar * secondary, gboolean cancel_button);
 void nullify_gstring (GString ** s);
 gchar *choose_file (gchar * title, gchar * startdir, GList * extensions);
+gchar *choose_directory (gchar * title, gchar * startdir, GList * extensions);
+gchar *try_to_find_file (gchar *base, gchar *filename);
 gchar *string_dialog_entry (DenemoProject * gui, gchar * title, gchar * instruction, gchar * initial_value);
 gchar *notes_choice_dialog (gint number_of_notes /* 1 or 2 */, gchar *initial_value, gchar *meaning);
 gchar *string_dialog_entry_with_widget (DenemoProject * gui, gchar * title, gchar * instruction, gchar * initial_value, GtkWidget * extra_widget);
