@@ -32,10 +32,8 @@
 #define EXCL_WIDTH 3
 #define EXCL_HEIGHT 13
 #define SAMPLERATE (44100) /* arbitrary large figure used if no audio */
-static DenemoObject *Startobj, *Endobj;
 static gboolean layout_needed = TRUE;   //Set FALSE when further call to draw_score(NULL) is not needed.
 static GList *MidiDrawObject;/* a chord used for drawing MIDI recorded notes on the score */
-
 static gboolean last_tied = FALSE;
 void
 initialize_playhead (void)
@@ -52,7 +50,7 @@ region_playhead (void)
 
 
 void
-set_start_and_end_objects_for_draw (void)
+fix_start_end_ordering (void)
 {
   if (Denemo.project->movement->smf)
     {
@@ -60,17 +58,11 @@ set_start_and_end_objects_for_draw (void)
       gdouble end = Denemo.project->movement->end_time;
       if ((end > 0.0) && (end < start))
         {
-#ifdef SWAPPING_ENDS
             Denemo.project->movement->start_time = end;
             Denemo.project->movement->end_time = start;
             start = Denemo.project->movement->start_time;
             end = Denemo.project->movement->end_time;
-#else
-            Denemo.project->movement->end_time = -1.0;
-#endif
         }
-      Startobj = get_obj_for_end_time (Denemo.project->movement->smf, start/get_playback_speed() + 0.001);
-      Endobj = Denemo.project->movement->end_time < 0.0 ? NULL : get_obj_for_start_time (Denemo.project->movement->smf, end/get_playback_speed() - 0.001);
     }
 }
 
@@ -146,13 +138,13 @@ struct infotopass
   gint *left, *right;           //pointer into array, pointing to leftmost/rightmost measurenum for current system(line)
   gint *scale;                  //pointer into an array of scales - this entry is the percent horizontal scale applied to the current system
   GList *last_midi;             //last list of midi events for object at right of window
-  DenemoObject *startobj;       //pointer values - if drawing such an object mark as playback start
-  DenemoObject *endobj;         //pointer values - if drawing such an object mark as playback end
   gint startposition;           //x coordinate where to start playing
   gint endposition;             //x coordinate where to end playing
   gint playposition;            //x coordinate of currently played music
   gdouble leftmosttime;         //MIDI time of left most object on last system line displayed
   gdouble rightmosttime;        //MIDI time of last object  displayed
+  GList *leftmostobj;           //left most object displayed
+  gboolean startisoffscreen;    //left most object is after the start time
   GList *recordednote;//list of notes when recorded audio or MIDI is present
   gint currentframe; //current frame of audio being played. (current time converted to frames (at si->recording->samplerate) and slowed down)
   gboolean highlight_next_note;//the last CHORD was the one before the currently playing one.
@@ -306,15 +298,20 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoProject * gui
   if (mudelaitem == Denemo.project->movement->playingnow)
     itp->playposition = x + mudelaitem->x;
 
-  if (mudelaitem == itp->startobj) {
-    itp->startposition = x + mudelaitem->x/* + mudelaitem->minpixelsalloted*/;
-    // if(curobj->prev==NULL) g_debug("item %p at %d\n", curobj, x+mudelaitem->x), itp->startposition -= mudelaitem->minpixelsalloted;
+  if (Denemo.project->movement->smf)
+    {
+      if ( (!itp->startisoffscreen) && (itp->startposition < 0) &&  (mudelaitem->earliest_time > (Denemo.project->movement->start_time - 0.001))) 
+        {
+          if (((curobj==itp->leftmostobj) && (fabs (mudelaitem->earliest_time - Denemo.project->movement->start_time)>0.001)))
+            itp->startisoffscreen = TRUE;
+          else
+            itp->startposition = x + mudelaitem->x;
+        }
+      if ((itp->endposition < 0) && (mudelaitem->latest_time >= Denemo.project->movement->end_time)) {
+        itp->endposition = x + mudelaitem->x + mudelaitem->minpixelsalloted;
+        }
     }
-
-  if (mudelaitem == itp->endobj)
-    itp->endposition = x + mudelaitem->x/* + mudelaitem->minpixelsalloted*/;
-
-
+ 
 
   if (cr)
     if (mudelaitem->type == CHORD && ((chord *) mudelaitem->object)->tone_node)
@@ -633,7 +630,7 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoProject * gui
       {
         DenemoDirective *directive = mudelaitem->object;
         if (cr)
-          draw_lily_dir (cr, x + mudelaitem->x, y, 0, 0, mudelaitem, itp->mark, (si->currentobject == curobj));
+          draw_lily_dir (cr, x + mudelaitem->x, y, 0, 0, mudelaitem, itp->mark, (Denemo.object_hovering_over==curobj) || (si->currentobject == curobj));
         if ((directive->ty - 10) < itp->highy)
           itp->highy = directive->ty - 10 /* for height of text */ ;
         if ((directive->gy - 10) < itp->highy)
@@ -894,6 +891,7 @@ draw_measure (cairo_t * cr, measurenode * curmeasure, gint x, gint y, DenemoProj
 
       if ((!curmeasure->next))
         {
+         
           /* we've reached the end of the staff and should
            * draw the heavy part of double-barline unless there is a directive here in which case it takes responsibility for the type of barline */
           x += 3;
@@ -903,8 +901,8 @@ draw_measure (cairo_t * cr, measurenode * curmeasure, gint x, gint y, DenemoProj
               cairo_fill (cr);
             }
           itp->end = TRUE;
-          if(itp->startposition>-1 && itp->endposition<0)
-            itp->endposition = x + GPOINTER_TO_INT (itp->mwidthiterator->data) + 5;//end play marker after last note if not elsewhere
+          //if(itp->startposition>-1 && itp->endposition<0)
+            //itp->endposition = x + GPOINTER_TO_INT (itp->mwidthiterator->data) + 5;//end play marker after last note if not elsewhere
         }
       else
         {
@@ -1100,9 +1098,7 @@ draw_staff (cairo_t * cr, staffnode * curstaff, gint y, DenemoProject * gui, str
 
 
 
-  if ((gui->movement->smf) && (itp->startobj == NULL) && (itp->startposition <= 0) && (si->leftmeasurenum == 1))
-    itp->startposition = x;
-
+ 
 
   /* Loop that will draw each measure. Basically a for loop, but was uglier
    * when written that way.  */
@@ -1123,6 +1119,7 @@ draw_staff (cairo_t * cr, staffnode * curstaff, gint y, DenemoProject * gui, str
           itp->leftmosttime = mudelaitem->earliest_time;
         else
           itp->leftmosttime = 1000000.0;
+        itp->leftmostobj = curobj;
       }
     //g_debug("Drawing staff %d leftmost time %f, measurenum %d\n",itp->staffnum, itp->leftmosttime, itp->measurenum);
   }
@@ -1283,11 +1280,11 @@ print_system_separator (cairo_t * cr, gdouble position)
 typedef enum colors
 { BLACK, RED, GREEN } colors;
 static void
-draw_playback_marker (cairo_t * cr, gint color, gint pos, gint yy, gint line_height)
+draw_playback_marker (cairo_t * cr, gint color, gdouble alpha, gint pos, gint yy, gint line_height)
 {
-  if (!Denemo.prefs.playback_controls)
-    return;
-  //g_debug("drawing marker %x at %d %d %d\n", color, pos, yy, line_height);
+  //if (!Denemo.prefs.playback_controls)
+  //  return;
+  //g_print("\n\tdrawing marker %s at x = %d y = %d", color==1?"Red":"Green", pos, yy);
   cairo_save (cr);
   cairo_set_line_width (cr, 4.0);
   switch (color)
@@ -1296,10 +1293,10 @@ draw_playback_marker (cairo_t * cr, gint color, gint pos, gint yy, gint line_hei
       cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.5);
       break;
     case GREEN:
-      cairo_set_source_rgba (cr, 0.0, 1.0, 0.0, 0.5);
+      cairo_set_source_rgba (cr, 0.0, 1.0, 0.0, alpha);
       break;
     case RED:
-      cairo_set_source_rgba (cr, 1.0, 0.0, 0.0, 0.5);
+      cairo_set_source_rgba (cr, 1.0, 0.0, 0.0, alpha);
       break;
     }
   cairo_move_to (cr, pos, yy - STAFF_HEIGHT);
@@ -1308,10 +1305,10 @@ draw_playback_marker (cairo_t * cr, gint color, gint pos, gint yy, gint line_hei
   switch (color)
     {
     case GREEN:
-      drawlargetext_cr (cr, _("Playback Start"), pos - 100, yy);
+      drawlargetext_cr (cr, _("Ctrl+Alt-Drag Start"), pos - 100, yy-LINE_SPACE);
       break;
     case RED:
-      drawlargetext_cr (cr, _("Playback End"), pos - 100, yy);
+      drawlargetext_cr (cr, _("Ctrl+Alt-Drag End"), pos - 100, yy-3*LINE_SPACE);
       break;
     }
   cairo_restore (cr);
@@ -1320,17 +1317,24 @@ draw_playback_marker (cairo_t * cr, gint color, gint pos, gint yy, gint line_hei
 static void
 draw_playback_markers (cairo_t * cr, struct infotopass *itp, gint yy, gint line_height)
 {
-
-  //  if(itp->playposition>-1)
-  //   draw_playback_marker(cr, BLACK, itp->playposition, yy, line_height);
-  //  itp->playposition = -1;
-
+  //g_print ("\nMarkers at staff %d for top %d with start %d end %d:", itp->staffnum, Denemo.project->movement->top_staff, itp->startposition, itp->endposition);
   if (itp->startposition > 0)
-    draw_playback_marker (cr, GREEN, itp->startposition, yy, line_height);
+    {
+      if (!(Denemo.dragging_start_playback_marker && Denemo.prefs.cursor_highlight ))
+        draw_playback_marker (cr, GREEN,0.4,itp->startposition, yy, line_height);
+      else
+        draw_playback_marker (cr, GREEN, 0.2,itp->startposition, yy, line_height);
+    }
   itp->startposition = -1;
 
   if (itp->endposition > 0)
-    draw_playback_marker (cr, RED, itp->endposition, yy, line_height);
+      {
+      if (!(Denemo.dragging_end_playback_marker && Denemo.prefs.cursor_highlight))
+        draw_playback_marker (cr, RED, 0.4, itp->endposition, yy, line_height);
+      else
+        draw_playback_marker (cr, RED, 0.2, itp->endposition, yy, line_height);
+    }
+
   itp->endposition = -1;
 }
 
@@ -1391,7 +1395,8 @@ draw_score (cairo_t * cr)
   itp.playposition = -1;
   itp.startposition = -1;
   itp.endposition = -1;
-  itp.startobj = itp.endobj = NULL;
+  itp.startisoffscreen = FALSE;
+  
   itp.tupletstart = itp.tuplety = 0;
   itp.recordednote = si->recording?si->recording->notes:NULL;
   itp.currentframe = (get_playback_time()/get_playback_speed())*(si->recording?si->recording->samplerate:SAMPLERATE);
@@ -1399,14 +1404,7 @@ draw_score (cairo_t * cr)
 
   if (Denemo.hidden_staff_heights)  g_list_free (Denemo.hidden_staff_heights);
   Denemo.hidden_staff_heights = NULL;
-  if (gui->movement->smf)
-    {
-      itp.startobj = Startobj;
-      //g_debug("start %p\n", itp.startobj);
 
-      itp.endobj = Endobj;
-      //g_debug("Start time %p %f end time %p %f\n", itp.startobj, si->start_time, itp.endobj, si->end_time);
-    }
   if (cr)
     cairo_translate (cr, movement_transition_offset (), 0);
   /* The colour for staff lines and such is black. */
@@ -1687,7 +1685,8 @@ draw_score (cairo_t * cr)
         repeat = TRUE;
 
       if (cr)
-        draw_playback_markers (cr, &itp, y, line_height);
+        if (itp.staffnum == si->top_staff)
+          draw_playback_markers (cr, &itp, y, line_height);
 
       gint system_num;
       system_num = 1;
