@@ -22,6 +22,6 @@ gint scorearea_draw_event (GtkWidget * widget, GdkEventExpose * event);
 #endif
 void update_drawing_cache (void);
 gboolean draw_score (cairo_t * cr);
-void set_start_and_end_objects_for_draw();
+void fix_start_end_ordering();
 void draw_score_area();
 #endif
