@@ -31,6 +31,9 @@
 #include "export/exportlilypond.h"
 #include "core/utils.h"
 
+gint LilyPond_stderr;       //A file descriptor to pipe for LilyPond's stderr
+GError *lily_err;
+GPid previewerpid;
 
 
 #if GTK_MAJOR_VERSION==3
@@ -424,8 +427,7 @@ open_viewer (gint status, gchar * filename)
 #if GLIB_CHECK_VERSION(2,34,0)
   {
     GError* err = NULL;
-    status = g_spawn_check_exit_status (status, &err);
-    if(!status)
+     if (!g_spawn_check_exit_status (status, &err))
         g_warning ("Lilypond did not end successfully: %s", err->message);
   }
 #endif
