@@ -21,6 +21,7 @@
 #include "audio/playback.h"
 #include "export/print.h"
 #include "core/view.h"
+#include "core/menusystem.h"
 #include "command/scorelayout.h"
 #include "command/lilydirectives.h"
 #include "export/exportlilypond.h"
@@ -337,33 +338,26 @@ playbackview_predraw_event (GtkWidget * widget, GdkEventExpose * event)
 
 static Timing *get_svg_position(gchar *id, GList *ids)
 {
-  gchar *locale = setlocale (LC_ALL, NULL);
+  Timing *timing = NULL;
   setlocale (LC_ALL, "C");
   for(;ids;ids=ids->next)
         {//g_print ("Testing %s with %s\n", ids->data, id);
             if (g_str_has_prefix ((gchar*)ids->data, id))
                 {
-
-                  Timing *timing = (Timing *)g_malloc (sizeof(Timing));
+                  timing = (Timing *)g_malloc (sizeof(Timing));
                   if (2==sscanf ((gchar*)ids->data, "Note-%*d-%*d translate(%lf,%lf)%*s%*s", &timing->x, &timing->y))
                     {
-                        //g_print ("Found Position %.2f %.2f\n", timing->x, timing->y);
-                        setlocale (LC_ALL, locale);
-                        return timing;
+                       break;
                     } else if (2==sscanf ((gchar*)ids->data, "Rest-%*d-%*d translate(%lf,%lf)%*s%*s", &timing->x, &timing->y))
                     {
-                       //g_print ("Found Position %.2f %.2f\n", timing->x, timing->y);
-                        setlocale (LC_ALL, locale);
-                        return timing;
+                      break;
                     }
-
                 }
-
-
         }
-    setlocale (LC_ALL, locale);
-    g_warning ("Failed to find a position in events.txt for %s, locale reset to %s\n", id, locale);
-    return NULL;
+    localization_init ();
+    if (timing==NULL)    
+        g_warning ("Failed to find a position in events.txt for %s\n", id);
+    return timing;
 }
 
 static void add_note (Timing *t)
