@@ -40,6 +40,7 @@ SCM scheme_call_callback (SCM optional, callback_function callback);
 
 void update_scheme_snippet_ids (void);
 
+SCM scheme_system (SCM);
 SCM scheme_hide_menus (SCM);
 SCM scheme_hide_buttons (SCM);
 SCM scheme_destroy_buttons (void);
@@ -108,6 +109,8 @@ SCM scheme_get_horizontal_position (void);
 SCM scheme_get_cursor_note (SCM);
 SCM scheme_get_cursor_note_with_octave (SCM);
 SCM scheme_get_editing_time (void);
+SCM scheme_set_editing_time (SCM secs);
+SCM scheme_clear_print_history (void);
 SCM scheme_debug_object (SCM);
 SCM scheme_display_object (void);
 SCM scheme_swap_display_and_source (void);
@@ -171,6 +174,7 @@ SCM scheme_diatonic_shift (SCM);
 SCM scheme_next_object (void);
 SCM scheme_prev_object (void);
 SCM scheme_next_object_in_measure (void);
+SCM scheme_is_measure_end (void);
 SCM scheme_prev_object_in_measure (void);
 SCM scheme_next_selected_object (SCM);
 SCM scheme_prev_selected_object (SCM);
@@ -330,13 +334,19 @@ SCM scheme_get_current_staff_layout_id (void);
 SCM scheme_select_layout_id (SCM);
 SCM scheme_lilypond_for_part (void);
 SCM scheme_typeset_part (void);
+SCM scheme_typeset_current_movement (void);
 SCM scheme_reduce_layout_to_lilypond (void);
 SCM scheme_get_layout_name (void);
 SCM scheme_select_next_layout (void);
 SCM scheme_select_first_layout (void);
 SCM scheme_select_next_custom_layout (void);
 SCM scheme_select_first_custom_layout (void);
+SCM scheme_get_omit_criterion (void);
+SCM scheme_set_omit_criterion (SCM name);
+SCM scheme_get_omit_criteria (void);
+SCM scheme_get_id_for_name (SCM name);
 SCM scheme_get_filename (void);
+SCM scheme_clear_filename (void);
 SCM scheme_select_tab (SCM index);
 SCM scheme_compare_objects (SCM index1, SCM index2, SCM move);
 SCM scheme_difference_of_staffs (SCM index1, SCM index2, SCM move);
@@ -733,8 +743,8 @@ SCM scheme_note_directive_get_gy (SCM);
 SCM scheme_chord_directive_put_gy (SCM tag, SCM value);
 SCM scheme_chord_directive_get_gy (SCM);
 SCM scheme_standalone_directive_put_allow (SCM tag, SCM value);
-SCM scheme_standalone_directive_get_x (SCM);
 SCM scheme_standalone_directive_put_ignore (SCM tag, SCM value);
+SCM scheme_standalone_directive_get_x (SCM);
 SCM scheme_standalone_directive_get_y (SCM);
 SCM scheme_standalone_directive_put_tx (SCM tag, SCM value);
 SCM scheme_standalone_directive_get_tx (SCM);
